/* Content of this CSS will be used in the pages rendered by gnome-web-photo.
 * Use "!important" to override a rule that might be specified in the CSS
 * of the page. See http://www.w3.org/TR/CSS2/cascade.html#important-rules */

/* The following can be used for pages containing one or multiple iframe(s),
   to get the whole content of the iframe(s) in the output.
   This is disabled by default, to offer an output as close as to what would be
   displayed in the browser. */
/*
html, body, iframe {
  overflow-y: hidden !important;
}

iframe {
  width: 100%;
  height: 100%;
}
 */
